@@ -2,10 +2,8 @@
 # this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
-from . import account
-from . import product
-from . import sale
-from . import stock
+
+from . import account, product, sale, stock
 
 __all__ = ['register']
 
@@ -27,3 +25,8 @@ def register():
         sale.OpportunityLine,
         module='sale_secondary_unit', type_='model',
         depends=['sale_opportunity'])
+    Pool.register(
+        sale.BlanketAgreementLine,
+        sale.LineBlanketAgreement,
+        module='sale_secondary_unit', type_='model',
+        depends=['sale_blanket_agreement'])
